@@ -1,15 +1,21 @@
+from svc_infra.api.fastapi.dual import (
+    DualAPIRouter,
+    dualize_protected,
+    dualize_public,
+    dualize_user,
+)
+
 from .cache.add import setup_caching
 from .deps import Require
-from .dual_router import DualAPIRouter, dualize_router
 from .ease import easy_service_api, easy_service_app
 from .models import APIVersionSpec, ServiceInfo
-from .routing import public_router
 from .setup import setup_service_api
 
 __all__ = [
     "DualAPIRouter",
-    "dualize_router",
-    "public_router",
+    "dualize_public",
+    "dualize_user",
+    "dualize_protected",
     "ServiceInfo",
     "APIVersionSpec",
     "Require",
