@@ -1,13 +1,14 @@
 from __future__ import annotations
 
 from datetime import datetime, timezone
-from typing import Optional
+from typing import Any, Optional
 
 from fastapi import Depends, HTTPException, Request, Security
 from fastapi.security import APIKeyCookie, APIKeyHeader, OAuth2PasswordBearer
 from sqlalchemy import select
 
 from svc_infra.api.fastapi.auth.settings import get_auth_settings
+from svc_infra.api.fastapi.auth.state import get_auth_state
 from svc_infra.api.fastapi.db.sql.session import SqlSessionDep
 from svc_infra.db.sql.apikey import get_apikey_model
 
@@ -67,64 +68,56 @@ async def resolve_api_key(
 
 
 async def resolve_bearer_or_cookie_principal(
-    request: Request,
-    session: SqlSessionDep,
+    request: Request, session: SqlSessionDep
 ) -> Optional[Principal]:
-    """
-    Try to authenticate a user via:
-      1) Authorization: Bearer <jwt>
-      2) auth cookie (settings.auth_cookie_name)
-    Returns None if neither is present/valid (so caller can try API key).
-    """
     st = get_auth_settings()
 
     raw_auth = (request.headers.get("authorization") or "").strip()
-    raw_bearer = ""
+    token = ""
     if raw_auth.lower().startswith("bearer "):
-        raw_bearer = raw_auth.split(" ", 1)[1].strip()
-
-    raw_cookie = (request.cookies.get(st.auth_cookie_name) or "").strip()
-
-    token = raw_bearer or raw_cookie
+        token = raw_auth.split(" ", 1)[1].strip()
+    if not token:
+        # try cookie
+        token = (request.cookies.get(st.auth_cookie_name) or "").strip()
     if not token:
         return None
 
-    # so we avoid importing app-specific models here.
-    # Discover User model via ApiKey relationship (only if API keys enabled)
-    ApiKey = get_apikey_model()  # <-- LAZY here
-    UserModel = ApiKey.user.property.mapper.class_
+    # Use the exact UserModel and JWTStrategy from boot:
+    UserModel, get_strategy, _ = get_auth_state()
+    strategy = get_strategy()
 
-    # Defer import to avoid circulars and to keep this infra module reusable.
-    from svc_infra.api.fastapi.db.sql.users import get_fastapi_users
+    # We still need a user_manager to satisfy fastapi-users’ read_token signature,
+    # but we don’t want to rebuild everything. Use a tiny, local manager shim.
+    from fastapi_users.manager import BaseUserManager, UUIDIDMixin
+    from fastapi_users_db_sqlalchemy import SQLAlchemyUserDatabase
 
-    fapi, auth_backend, *_ = get_fastapi_users(
-        UserModel, None, None, None, public_auth_prefix="/auth"
-    )
+    user_db = SQLAlchemyUserDatabase(session, UserModel)
 
-    # fastapi-users needs a real user_manager instance to read tokens
-    user_manager_gen = fapi.get_user_manager  # async generator
-    strategy = auth_backend.get_strategy()
+    class _ShimManager(UUIDIDMixin, BaseUserManager[Any, Any]):
+        reset_password_token_secret = "unused"
+        verification_token_secret = "unused"
 
-    user = None
-    async for user_manager in user_manager_gen():  # type: ignore
-        try:
-            user = await strategy.read_token(token, user_manager)
-        finally:
-            break
+        # fastapi-users only needs .user_db for read_token()
+        def __init__(self, db):
+            super().__init__(db)
 
+    user_manager = _ShimManager(user_db)
+
+    try:
+        user = await strategy.read_token(token, user_manager)
+    except Exception:
+        return None
     if not user:
-        return None  # let API key fallback try
+        return None
 
-    # Rehydrate into *your* session so it's the real ORM instance
+    # Rehydrate into your ORM session
     db_user = await session.get(UserModel, user.id)
     if not db_user:
         return None
-
-    # Enforce active status (keeps parity with your other guards)
     if not getattr(db_user, "is_active", True):
         raise HTTPException(401, "account_disabled")
 
-    via = "jwt" if raw_bearer else "cookie"
+    via = "jwt" if raw_auth else "cookie"
     return Principal(user=db_user, scopes=[], via=via)
 
 
